@@ -13,9 +13,11 @@ from audb.core import define
 from audb.core.config import config
 from audb.core.dependencies import Dependencies
 from audb.core.flavor import Flavor
+from audb.core.repository import Repository
 from audb.core.utils import (
     lookup_backend,
     mix_mapping,
+    _lookup,
 )
 
 
@@ -26,12 +28,19 @@ def available(
     r"""List all databases that are available to the user.
 
     Args:
-        only_latest: keep only latest version
+        only_latest: include only latest version of database
 
     Returns:
-        table with name, version and private flag
+        table with database name as index,
+        and backend, host, repository, version as columns
 
-    """
+    Example:
+        >>> audb.available(only_latest=True)
+                   backend                                    host   repository version
+        name
+        emodb  artifactory  https://audeering.jfrog.io/artifactory  data-public   1.1.1
+
+    """  # noqa: E501
     databases = []
     for repository in config.REPOSITORIES:
         backend = audbackend.create(
@@ -86,7 +95,7 @@ def cached(
         name: str = None,
         shared: bool = False,
 ) -> pd.DataFrame:
-    r"""List available databases in the cache.
+    r"""List available databases and flavors in the cache.
 
     Args:
         cache_root: cache folder where databases are stored.
@@ -94,12 +103,43 @@ def cached(
         name: name of database.
             If provided,
             it will show only cached versions of that database
-        shared: list shared databases
+        shared: include databases from shared cache
 
     Returns:
         cached databases
+        with cache path as index,
+        and name,
+        flavor_id,
+        version,
+        complete,
+        bit_depth,
+        channels,
+        format,
+        mixdown,
+        sampling_rate
+        as columns
 
-    """
+    Example:
+        >>> db = audb.load(
+        ...     'emodb',
+        ...     version='1.1.1',
+        ...     only_metadata=True,
+        ...     full_path=False,
+        ...     verbose=False,
+        ... )
+        >>> df = cached()
+        >>> print(df.iloc[0].to_string())
+        name                emodb
+        flavor_id        d3b62a9b
+        version             1.1.1
+        complete            False
+        bit_depth            None
+        channels             None
+        format               None
+        mixdown             False
+        sampling_rate        None
+
+    """  # noqa: E501
     cache_root = audeer.safe_path(
         cache_root or default_cache_root(shared=shared)
     )
@@ -229,13 +269,18 @@ def dependencies(
 
     Args:
         name: name of database
-        version: version string
+        version: version of database
         cache_root: cache folder where databases are stored.
             If not set :meth:`audb.default_cache_root` is used
 
     Returns:
         dependency object
 
+    Example:
+        >>> deps = dependencies('emodb', version='1.1.1')
+        >>> deps.version('db.emotion.csv')
+        '1.1.0'
+
     """
     if version is None:
         version = latest_version(name)
@@ -259,7 +304,9 @@ def dependencies(
     deps_path = os.path.join(deps_root, define.CACHED_DEPENDENCIES_FILE)
 
     deps = Dependencies()
-    if not os.path.exists(deps_path):
+    try:
+        deps.load(deps_path)
+    except (FileNotFoundError, ValueError, EOFError):
         backend = lookup_backend(name, version)
         with tempfile.TemporaryDirectory() as tmp_root:
             archive = backend.join(name, define.DB)
@@ -270,8 +317,6 @@ def dependencies(
             )
             deps.load(os.path.join(tmp_root, define.DEPENDENCIES_FILE))
             deps.save(deps_path)
-    else:
-        deps.load(deps_path)
 
     return deps
 
@@ -316,6 +361,18 @@ def exists(
     Returns:
         ``True`` if database flavor exists
 
+    Example:
+        >>> db = audb.load(
+        ...     'emodb',
+        ...     version='1.1.1',
+        ...     only_metadata=True,
+        ...     verbose=False,
+        ... )
+        >>> audb.exists('emodb', version='1.1.1')
+        True
+        >>> audb.exists('emodb', version='1.1.1', format='wav')
+        False
+
     """
     # Map mix to channels and mixdown
     if (
@@ -393,6 +450,10 @@ def flavor_path(
     Returns:
         flavor path relative to cache folder
 
+    Example:
+        >>> flavor_path('emodb', version='1.1.1')
+        'emodb/1.1.1/d3b62a9b'
+
     """
     flavor = Flavor(
         channels=channels,
@@ -416,6 +477,10 @@ def latest_version(
     Returns:
         version string
 
+    Example:
+        >>> latest_version('emodb')
+        '1.1.1'
+
     """
     vs = versions(name)
     if not vs:
@@ -433,6 +498,11 @@ def remove_media(
 ):
     r"""Remove media from all versions.
 
+    Be careful,
+    this removes files from all published versions
+    on all backends.
+    Those files cannot be restored afterwards.
+
     Args:
         name: name of database
         files: list of files that should be removed
@@ -508,6 +578,35 @@ def remove_media(
                 )
 
 
+def repository(
+        name: str,
+        version: str,
+) -> Repository:
+    r"""Return repository that stores the requested database.
+
+    If the database is stored in several repositories,
+    only the first one is returned.
+    The order of the repositories to look for the database
+    is given by :attr:`config.REPOSITORIES`.
+
+    Args:
+        name: database name
+        version: version string
+
+    Returns:
+        repository that contains the database
+
+    Raises:
+        RuntimeError: if database is not found
+
+    Example:
+        >>> audb.repository('emodb', '1.1.1')
+        Repository('data-public', 'https://audeering.jfrog.io/artifactory', 'artifactory')
+
+    """  # noqa: E501
+    return _lookup(name, version)[0]
+
+
 def versions(
         name: str,
 ) -> typing.List[str]:
@@ -519,6 +618,10 @@ def versions(
     Returns:
         list of versions
 
+    Example:
+        >>> versions('emodb')
+        ['1.1.0', '1.1.1']
+
     """
     vs = []
     for repository in config.REPOSITORIES:
